Re-exports
pub use registry::RawTypedUserDataRegistry;pub use registry::TypedDataDocumentation;pub use registry::TypedDataFields;pub use registry::TypedDataMethods;pub use registry::TypedUserData;pub use registry::TypedUserDataRegistry;
Modules
Structs
- Field
- Type information for a lua
classfield - Func
- Type information for a lua
classfunction - Param
- A function parameter type representation
- Return
- A function parameter type representation
- Static
Field - Type information for a lua
classfield - Typed
Function - Helper to bake the type information for a lua
Function. This makes repeated calls to theFunction’scallall the same with enforced arguments and return types.
Enums
Traits
- Into
DocComment - Helper that converts multiple different types into an
Option<Cow<'static, str>> - Into
LuaType Literal - Typed
- Add a lua
Typerepresentation to a rust type - Typed
Multi Value - Typed information for a lua
MultiValue