pub struct Entry {
pub doc: Option<String>,
pub name: String,
pub ty: Type,
}Expand description
Representation of a type that is defined in the definition file.
This type has a name and additional documentation that can be displayed
Fields
doc: Option<String>name: Stringty: TypeImplementations