pub struct TypedFunction<Params, Response>where
Params: TypedMultiValue,
Response: TypedMultiValue,{ /* private fields */ }Expand description
Implementations
Sourceimpl<Params, Response> TypedFunction<Params, Response>
impl<Params, Response> TypedFunction<Params, Response>
Sourcepub fn call(&self, params: Params) -> Result<Response>
pub fn call(&self, params: Params) -> Result<Response>
Same as Function::call but with the param and return types already specified
Sourcepub unsafe fn call_unsafe(&self, params: Params) -> Response
pub unsafe fn call_unsafe(&self, params: Params) -> Response
Same as Function::call but with the param and return types already specified
Safety
Panics if any lua errors occur
Sourcepub fn from_rust<F>(&self, lua: &Lua, func: F) -> Result<Self>where
Params: TypedMultiValue + FromLuaMulti,
Response: TypedMultiValue + IntoLuaMulti,
F: Fn(&Lua, Params) -> Result<Response> + MaybeSend + 'static,
pub fn from_rust<F>(&self, lua: &Lua, func: F) -> Result<Self>where
Params: TypedMultiValue + FromLuaMulti,
Response: TypedMultiValue + IntoLuaMulti,
F: Fn(&Lua, Params) -> Result<Response> + MaybeSend + 'static,
Create a typed function from a rust function.
This will call Lua::create_function under the hood