Module typed

Module typed 

Modules

generator

Structs

Field
Type information for a lua class field
Func
Type information for a lua class function
Param
A function parameter type representation
Return
A function parameter type representation
StaticField
Type information for a lua class field
TypedClass
TypedClassBuilder
Type information for a lua class. This happens to be a TypedUserData
TypedFunction
Helper to bake the type information for a lua Function. This makes repeated calls to the Function’s call all the same with enforced arguments and return types.
WrappedBuilder
Wrapper around a UserDataFields and UserDataMethods to allow TypedUserData implementations to be used for mlua::UserData implementations

Enums

Index
Represents a lua table key
Type
Representation of a lua type for a rust type

Traits

IntoDocComment
Helper that converts multiple different types into an Option<Cow<'static, str>>
IntoLuaTypeLiteral
Typed
Add a lua Type representation to a rust type
TypedDataDocumentation
Used inside of TypedUserData to add doc comments to the userdata type itself
TypedDataFields
Typed variant of mlua::UserDataFields
TypedDataMethods
Typed variant of mlua::UserDataMethods
TypedMultiValue
Typed information for a lua MultiValue
TypedUserData
Typed variant of mlua::UserData