TypedClassBuilder

Struct TypedClassBuilder 

pub struct TypedClassBuilder {
    pub typed_class: TypedClass,
    /* private fields */
}
Type information for a lua class. This happens to be a TypedUserData

Fields

typed_class: TypedClass

Implementations

Source

impl TypedClassBuilder

pub fn new<T: TypedUserData>() -> Self

pub fn build(self) -> TypedClass

pub fn skip_field(self, idx: impl Into<Index>) -> Self

Skip/Remove a field field from the class definition

pub fn skip_method(self, idx: impl Into<Index>) -> Self

Skip/Remove a method from the class definition

pub fn skip_meta_method(self, idx: impl Into<Index>) -> Self

Skip/Remove a meta method from the class definition

pub fn skip_function(self, idx: impl Into<Index>) -> Self

Skip/Remove a function from the class definition

pub fn skip_meta_function(self, idx: impl Into<Index>) -> Self

Skip/Remove a meta function from the class definition

pub fn field( self, key: impl Into<Index>, ty: Type, doc: impl IntoDocComment, ) -> Self

Creates a new typed field and adds it to the class’s type information

Example
use mlua_extras::typed::{TypedClassBuilder, Type};

static NAME: &str = "mlua_extras";

TypedClassBuilder::default()
    .field("data1", Type::string() | Type::nil(), "doc comment goes last")
    .field("data2", Type::array(Type::string()), ()) // Can also use `None` instead of `()`
    .field("message", Type::string(), format!("A message for {NAME}"));
pub fn static_field<V>( self, key: impl Into<Index>, value: V, doc: impl IntoDocComment, ) -> Self
where V: Typed + IntoLua,

pub fn inherit(self, parent: &TypedClass) -> Self

pub fn function<Params, Returns>( self, key: impl Into<Index>, doc: impl IntoDocComment, ) -> Self
where Params: TypedMultiValue, Returns: TypedMultiValue,

Creates a new typed function and adds it to the class’s type information

Example
use mlua_extras::typed::{TypedClassBuilder, Type};

TypedClassBuilder::default()
    .function::<String, ()>("greet", "Greet the given name")
    // Can use `None` instead of `()` for specifying the doc comment
    .function::<String, ()>("hello", ());
pub fn method<Params, Returns>( self, key: impl Into<Index>, doc: impl IntoDocComment, ) -> Self
where Params: TypedMultiValue, Returns: TypedMultiValue,

Creates a new typed method and adds it to the class’s type information.

As with methods in lua, the self parameter is implicit and has the same type as the parent class.

Example
use mlua_extras::typed::{TypedClassBuilder, Type};

TypedClassBuilder::default()
    .method::<String, ()>("greet", "Greet the given name")
    // Can use `None` instead of `()` for specifying the doc comment
    .method::<String, ()>("hello", ());
pub fn meta_field( self, key: impl Into<Index>, ty: Type, doc: impl IntoDocComment, ) -> Self

Creates a new typed field and adds it to the class’s meta type information

Example
use mlua_extras::typed::{TypedClassBuilder, Type};

static NAME: &str = "mlua_extras";

TypedClassBuilder::default()
    .meta_field("data1", Type::string() | Type::nil(), "doc comment goes last")
    .meta_field("data2", Type::array(Type::string()), ()) // Can also use `None` instead of `()`
    .meta_field("message", Type::string(), format!("A message for {NAME}"));
pub fn meta_function<Params, Returns>( self, key: impl Into<Index>, doc: impl IntoDocComment, ) -> Self
where Params: TypedMultiValue, Returns: TypedMultiValue,

Creates a new typed function and adds it to the class’s meta type information

Example
use mlua_extras::typed::{TypedClassBuilder, Type};

TypedClassBuilder::default()
    .meta_function::<String, ()>("greet", "Greet the given name")
    // Can use `None` instead of `()` for specifying the doc comment
    .meta_function::<String, ()>("hello", ());
pub fn meta_method<Params, Returns>( self, key: impl Into<Index>, doc: impl IntoDocComment, ) -> Self
where Params: TypedMultiValue, Returns: TypedMultiValue,

Creates a new typed method and adds it to the class’s type information.

As with methods in lua, the self parameter is implicit and has the same type as the parent class.

Example
use mlua_extras::typed::{TypedClassBuilder, Type};

static NAME: &str = "mlua_extras";

TypedClassBuilder::default()
    .method::<String, ()>("greet", "Greet the given name")
    // Can use `None` instead of `()` for specifying the doc comment
    .method::<String, ()>("hello", ());
pub fn derive(self, parent: impl Display) -> Self

Add a child class that this class derives