TypedFunction

Struct TypedFunction 

pub struct TypedFunction<Params, Response>
where Params: TypedMultiValue, Response: TypedMultiValue,
{ /* private fields */ }
Helper to bake the type information for a lua Function. This makes repeated calls to the Function’s call all the same with enforced arguments and return types.

Implementations

Source

impl<Params, Response> TypedFunction<Params, Response>

pub fn call(&self, params: Params) -> Result<Response>

Same as Function::call but with the param and return types already specified

pub unsafe fn call_unsafe(&self, params: Params) -> Response

Same as Function::call but with the param and return types already specified

Safety

Panics if any lua errors occur

pub fn from_rust<F>(&self, lua: &Lua, func: F) -> Result<Self>
where Params: TypedMultiValue + FromLuaMulti, Response: TypedMultiValue + IntoLuaMulti, F: Fn(&Lua, Params) -> Result<Response> + MaybeSend + 'static,

Create a typed function from a rust function.

This will call Lua::create_function under the hood